package com.usky.fire.controller.web;


import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.bean.CommonPage;
import com.usky.fire.domain.DemFireAccidentDesc;
import com.usky.fire.service.DemFireAccidentDescService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * <p>
 * 火灾事故说明总表 前端控制器
 * </p>
 *
 * @author JCB
 * @since 2022-09-13
 */
@RestController
@RequestMapping("/demFireAccidentDesc")
public class DemFireAccidentDescController {

    @Autowired
    private DemFireAccidentDescService demFireAccidentDescService;

    /**
     * 火灾事故说明信息列表查询
     *
     * @param companyCode 单位编号
     * @param startDate   开始时间
     * @param endDate     结束时间
     * @param pageNum     当前页
     * @param pageSize    每页条数
     * @return
     */
    @GetMapping("fireAccidentExplainList")
    public ApiResult<CommonPage<DemFireAccidentDesc>> fireAccidentExplainList(@RequestParam(value = "companyCode", required = false) String companyCode,
                                                                              @RequestParam(value = "startDate", required = false) String startDate,
                                                                              @RequestParam(value = "endDate", required = false) String endDate,
                                                                              @RequestParam(value = "pageNum", required = false, defaultValue = "1") Integer pageNum,
                                                                              @RequestParam(value = "pageSize", required = false, defaultValue = "10") Integer pageSize) {
        return ApiResult.success(demFireAccidentDescService.fireAccidentExplainList(companyCode, startDate, endDate, pageNum, pageSize));
    }

    /**
     * 火灾事故统计信息查询
     *
     * @param companyCode 单位编号
     * @param startDate   开始时间
     * @param endDate     结束时间
     * @return
     */
    @GetMapping("fireAccidentStatistic")
    public ApiResult<List<DemFireAccidentDesc>> fireAccidentStatistic(@RequestParam(value = "companyCode", required = false) String companyCode,
                                                                      @RequestParam(value = "startDate", required = false) String startDate,
                                                                      @RequestParam(value = "endDate", required = false) String endDate) {
        return ApiResult.success(demFireAccidentDescService.fireAccidentStatistic(companyCode, startDate, endDate));
    }

    /**
     * 简易火灾事故认定书数据查询
     *
     * @param companyCode 单位编号
     * @param startDate   开始时间
     * @param endDate     结束时间
     * @return
     */
    @GetMapping("fireAccidentSimpleConList")
    public ApiResult<List<DemFireAccidentDesc>> fireAccidentSimpleConList(@RequestParam(value = "companyCode", required = false) String companyCode,
                                                                          @RequestParam(value = "startDate", required = false) String startDate,
                                                                          @RequestParam(value = "endDate", required = false) String endDate) {
        return ApiResult.success(demFireAccidentDescService.fireAccidentSimpleConList(companyCode, startDate, endDate));
    }

    /**
     * 火灾事故认定书数据查询
     *
     * @param companyCode 单位编号
     * @param startDate   开始时间
     * @param endDate     结束时间
     * @return
     */
    @GetMapping("fireAccidentConList")
    public ApiResult<List<DemFireAccidentDesc>> fireAccidentConList(@RequestParam(value = "companyCode", required = false) String companyCode,
                                                                    @RequestParam(value = "startDate", required = false) String startDate,
                                                                    @RequestParam(value = "endDate", required = false) String endDate) {
        return ApiResult.success(demFireAccidentDescService.fireAccidentConList(companyCode, startDate, endDate));
    }

}

